WatchMask

Struct WatchMask 

pub struct WatchMask(/* private fields */);
Describes a file system watch

Passed to Watches::add, to describe what file system events to watch for, and how to do that.

Examples

WatchMask constants can be passed to Watches::add as is. For example, here’s how to create a watch that triggers an event when a file is accessed:

inotify.watches().add("/tmp/inotify-rs-test-file", WatchMask::ACCESS)
   .expect("Error adding watch");

You can also combine multiple WatchMask constants. Here we add a watch this is triggered both when files are created or deleted in a directory:

inotify.watches().add("/tmp/", WatchMask::CREATE | WatchMask::DELETE)
   .expect("Error adding watch");

Implementations

Source

impl WatchMask

pub const ACCESS: Self

File was accessed

When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.

See inotify_sys::IN_ACCESS.

pub const ATTRIB: Self

Metadata (permissions, timestamps, …) changed

When watching a directory, this event can be triggered for the directory itself, as well as objects inside the directory.

See inotify_sys::IN_ATTRIB.

pub const CLOSE_WRITE: Self

File opened for writing was closed

When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.

See inotify_sys::IN_CLOSE_WRITE.

pub const CLOSE_NOWRITE: Self

File or directory not opened for writing was closed

When watching a directory, this event can be triggered for the directory itself, as well as objects inside the directory.

See inotify_sys::IN_CLOSE_NOWRITE.

pub const CREATE: Self

File/directory created in watched directory

When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.

See inotify_sys::IN_CREATE.

pub const DELETE: Self

File/directory deleted from watched directory

When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.

See inotify_sys::IN_DELETE.

pub const DELETE_SELF: Self

Watched file/directory was deleted

See inotify_sys::IN_DELETE_SELF.

pub const MODIFY: Self

File was modified

When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.

See inotify_sys::IN_MODIFY.

pub const MOVE_SELF: Self

Watched file/directory was moved

See inotify_sys::IN_MOVE_SELF.

pub const MOVED_FROM: Self

File was renamed/moved; watched directory contained old name

When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.

See inotify_sys::IN_MOVED_FROM.

pub const MOVED_TO: Self

File was renamed/moved; watched directory contains new name

When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.

See inotify_sys::IN_MOVED_TO.

pub const OPEN: Self

File or directory was opened

When watching a directory, this event can be triggered for the directory itself, as well as objects inside the directory.

See inotify_sys::IN_OPEN.

pub const ALL_EVENTS: Self

Watch for all events

This constant is simply a convenient combination of the following other constants:

See inotify_sys::IN_ALL_EVENTS.

pub const MOVE: Self

Watch for all move events

This constant is simply a convenient combination of the following other constants:

See inotify_sys::IN_MOVE.

pub const CLOSE: Self

Watch for all close events

This constant is simply a convenient combination of the following other constants:

See inotify_sys::IN_CLOSE.

pub const DONT_FOLLOW: Self

Don’t dereference the path if it is a symbolic link

See inotify_sys::IN_DONT_FOLLOW.

Filter events for directory entries that have been unlinked

See inotify_sys::IN_EXCL_UNLINK.

pub const MASK_ADD: Self

If a watch for the inode exists, amend it instead of replacing it

See inotify_sys::IN_MASK_ADD.

pub const ONESHOT: Self

Only receive one event, then remove the watch

See inotify_sys::IN_ONESHOT.

pub const ONLYDIR: Self

Only watch path, if it is a directory

See inotify_sys::IN_ONLYDIR.

Source

impl WatchMask

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in self are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in other are also set in self.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in other are also set in self.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in self and other.

pub fn remove(&mut self, other: Self)

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in self and other.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in self and other.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in self and other.

pub const fn difference(self, other: Self) -> Self

The intersection of self with the complement of other (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in self and other.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in self, truncating the result.

Source

impl WatchMask

pub const fn iter(&self) -> Iter<WatchMask>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<WatchMask>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl WatchMask

pub unsafe fn from_bits_unchecked(bits: u32) -> Self

👎Deprecated:

Use the safe from_bits_retain method instead

Wrapper around Self::from_bits_retain for backwards compatibility

Safety

This function is not actually unsafe. It is just a wrapper around the safe Self::from_bits_retain.