pub struct WatchMask(/* private fields */);Expand description
Describes a file system watch
Passed to Watches::add, to describe what file system events
to watch for, and how to do that.
Examples
WatchMask constants can be passed to Watches::add as is. For
example, here’s how to create a watch that triggers an event when a file
is accessed:
inotify.watches().add("/tmp/inotify-rs-test-file", WatchMask::ACCESS)
.expect("Error adding watch");You can also combine multiple WatchMask constants. Here we add a watch
this is triggered both when files are created or deleted in a directory:
inotify.watches().add("/tmp/", WatchMask::CREATE | WatchMask::DELETE)
.expect("Error adding watch");Implementations
Sourceimpl WatchMask
impl WatchMask
Sourcepub const ACCESS: Self
pub const ACCESS: Self
File was accessed
When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.
Sourcepub const ATTRIB: Self
pub const ATTRIB: Self
Metadata (permissions, timestamps, …) changed
When watching a directory, this event can be triggered for the directory itself, as well as objects inside the directory.
Sourcepub const CLOSE_WRITE: Self
pub const CLOSE_WRITE: Self
File opened for writing was closed
When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.
Sourcepub const CLOSE_NOWRITE: Self
pub const CLOSE_NOWRITE: Self
File or directory not opened for writing was closed
When watching a directory, this event can be triggered for the directory itself, as well as objects inside the directory.
Sourcepub const CREATE: Self
pub const CREATE: Self
File/directory created in watched directory
When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.
Sourcepub const DELETE: Self
pub const DELETE: Self
File/directory deleted from watched directory
When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.
Sourcepub const DELETE_SELF: Self
pub const DELETE_SELF: Self
Watched file/directory was deleted
Sourcepub const MODIFY: Self
pub const MODIFY: Self
File was modified
When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.
Sourcepub const MOVED_FROM: Self
pub const MOVED_FROM: Self
File was renamed/moved; watched directory contained old name
When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.
Sourcepub const MOVED_TO: Self
pub const MOVED_TO: Self
File was renamed/moved; watched directory contains new name
When watching a directory, this event is only triggered for objects inside the directory, not the directory itself.
Sourcepub const OPEN: Self
pub const OPEN: Self
File or directory was opened
When watching a directory, this event can be triggered for the directory itself, as well as objects inside the directory.
See inotify_sys::IN_OPEN.
Sourcepub const ALL_EVENTS: Self
pub const ALL_EVENTS: Self
Watch for all events
This constant is simply a convenient combination of the following other constants:
Sourcepub const MOVE: Self
pub const MOVE: Self
Watch for all move events
This constant is simply a convenient combination of the following other constants:
See inotify_sys::IN_MOVE.
Sourcepub const CLOSE: Self
pub const CLOSE: Self
Watch for all close events
This constant is simply a convenient combination of the following other constants:
Sourcepub const DONT_FOLLOW: Self
pub const DONT_FOLLOW: Self
Don’t dereference the path if it is a symbolic link
Sourcepub const EXCL_UNLINK: Self
pub const EXCL_UNLINK: Self
Filter events for directory entries that have been unlinked
Sourceimpl WatchMask
impl WatchMask
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl WatchMask
impl WatchMask
Sourcepub const fn iter(&self) -> Iter<WatchMask>
pub const fn iter(&self) -> Iter<WatchMask>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WatchMask>
pub const fn iter_names(&self) -> IterNames<WatchMask>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl WatchMask
impl WatchMask
Sourcepub unsafe fn from_bits_unchecked(bits: u32) -> Self
👎Deprecated: Use the safe from_bits_retain method instead
pub unsafe fn from_bits_unchecked(bits: u32) -> Self
Use the safe from_bits_retain method instead
Wrapper around Self::from_bits_retain for backwards compatibility
Safety
This function is not actually unsafe. It is just a wrapper around the
safe Self::from_bits_retain.